Struct ServiceList
struct ServiceList<T> { ... }
where
T: IntoIterator
Static service discovery based on a predetermined list of services.
ServiceList is created with an initial list of services. The discovery
process will yield this list once and do nothing after.
Implementations
impl<T, U> ServiceList<T>
fn new<Request>(services: T) -> ServiceList<T> where U: Service<Request>
impl<'__pin, T> Unpin for ServiceList<T>
impl<K, S, E, D> Discover for ServiceList<T>
fn poll_discover(self: Pin<&mut D>, cx: &mut Context<'_>) -> Poll<Option<Result<<D as TryStream>::Ok, <D as TryStream>::Error>>>
impl<S> TryStreamExt for ServiceList<T>
impl<S, T, E> TryStream for ServiceList<T>
fn try_poll_next(self: Pin<&mut S>, cx: &mut Context<'_>) -> Poll<Option<Result<<S as TryStream>::Ok, <S as TryStream>::Error>>>
impl<T> Any for ServiceList<T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ServiceList<T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ServiceList<T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> Debug for ServiceList<T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T> Freeze for ServiceList<T>
impl<T> From for ServiceList<T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for ServiceList<T>
impl<T> RefUnwindSafe for ServiceList<T>
impl<T> Send for ServiceList<T>
impl<T> StreamExt for ServiceList<T>
impl<T> Sync for ServiceList<T>
impl<T> UnsafeUnpin for ServiceList<T>
impl<T> UnwindSafe for ServiceList<T>
impl<T> WithSubscriber for ServiceList<T>
impl<T, U> Into for ServiceList<T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> Stream for ServiceList<T>
fn poll_next(self: Pin<&mut Self>, _: &mut Context<'_>) -> Poll<Option<<Self as >::Item>>
impl<T, U> TryFrom for ServiceList<T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ServiceList<T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>