Struct AsyncFilterLayer

struct AsyncFilterLayer<U> { ... }

Conditionally dispatch requests to the inner service based on an asynchronous predicate.

This Layer produces instances of the AsyncFilter service.

Implementations

impl<U> AsyncFilterLayer<U>

const fn new(predicate: U) -> Self

Returns a new layer that produces AsyncFilter services with the given AsyncPredicate.

impl<T> Any for AsyncFilterLayer<U>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for AsyncFilterLayer<U>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for AsyncFilterLayer<U>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for AsyncFilterLayer<U>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for AsyncFilterLayer<U>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for AsyncFilterLayer<U>

impl<T> ToOwned for AsyncFilterLayer<U>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for AsyncFilterLayer<U>

impl<T, U> Into for AsyncFilterLayer<U>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for AsyncFilterLayer<U>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for AsyncFilterLayer<U>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<U> Freeze for AsyncFilterLayer<U>

impl<U> RefUnwindSafe for AsyncFilterLayer<U>

impl<U> Send for AsyncFilterLayer<U>

impl<U> Sync for AsyncFilterLayer<U>

impl<U> Unpin for AsyncFilterLayer<U>

impl<U> UnsafeUnpin for AsyncFilterLayer<U>

impl<U> UnwindSafe for AsyncFilterLayer<U>

impl<U: $crate::clone::Clone> Clone for AsyncFilterLayer<U>

fn clone(self: &Self) -> AsyncFilterLayer<U>

impl<U: $crate::fmt::Debug> Debug for AsyncFilterLayer<U>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<U: Clone, S> Layer for AsyncFilterLayer<U>

fn layer(self: &Self, service: S) -> <Self as >::Service