Struct FilterLayer

struct FilterLayer<U> { ... }

Conditionally dispatch requests to the inner service based on a synchronous predicate.

This Layer produces instances of the Filter service.

Implementations

impl<U> FilterLayer<U>

const fn new(predicate: U) -> Self

Returns a new layer that produces Filter services with the given Predicate.

impl<T> Any for FilterLayer<U>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for FilterLayer<U>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for FilterLayer<U>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for FilterLayer<U>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for FilterLayer<U>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for FilterLayer<U>

impl<T> ToOwned for FilterLayer<U>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for FilterLayer<U>

impl<T, U> Into for FilterLayer<U>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for FilterLayer<U>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for FilterLayer<U>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<U> Freeze for FilterLayer<U>

impl<U> RefUnwindSafe for FilterLayer<U>

impl<U> Send for FilterLayer<U>

impl<U> Sync for FilterLayer<U>

impl<U> Unpin for FilterLayer<U>

impl<U> UnsafeUnpin for FilterLayer<U>

impl<U> UnwindSafe for FilterLayer<U>

impl<U: $crate::clone::Clone> Clone for FilterLayer<U>

fn clone(self: &Self) -> FilterLayer<U>

impl<U: $crate::fmt::Debug> Debug for FilterLayer<U>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<U: Clone, S> Layer for FilterLayer<U>

fn layer(self: &Self, service: S) -> <Self as >::Service