Struct Rate

struct Rate { ... }

A rate of requests per time period.

Implementations

impl Rate

const fn new(num: u64, per: Duration) -> Self

Create a new rate.

Panics

This function panics if num or per is 0.

impl Clone for Rate

fn clone(self: &Self) -> Rate

impl Copy for Rate

impl Debug for Rate

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl Freeze for Rate

impl RefUnwindSafe for Rate

impl Send for Rate

impl Sync for Rate

impl Unpin for Rate

impl UnsafeUnpin for Rate

impl UnwindSafe for Rate

impl<T> Any for Rate

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Rate

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Rate

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Rate

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Rate

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for Rate

impl<T> ToOwned for Rate

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for Rate

impl<T, U> Into for Rate

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Rate

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Rate

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>