pub struct ExponentialBackoff<R = HasherRng> { /* private fields */ }Expand description
A jittered exponential backoff strategy.
The backoff duration will increase exponentially for every subsequent backoff, up to a maximum duration. A small amount of random jitter is added to each backoff duration, in order to avoid retry spikes.