SubscriptionSource

Trait SubscriptionSource 

pub trait SubscriptionSource: Send + Sync {
    // Required method
    fn subscribe(
        &self,
        filter: ScryerFilter,
        rule_id: &RuleId,
    ) -> Box<dyn EventStream>;
}
Source of scryer subscriptions. One implementation per machine (local + one per remote peer).

Tower opens one subscription per rule by calling subscribe. The returned stream is owned by the supervisor and dropped when the rule is disabled.

Required Methods

fn subscribe( &self, filter: ScryerFilter, rule_id: &RuleId, ) -> Box<dyn EventStream>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors