Struct MapErr

struct MapErr<S, F> { ... }

Service returned by the map_err combinator.

Implementations

impl<S, F> MapErr<S, F>

const fn new(inner: S, f: F) -> Self

Creates a new MapErr service.

fn layer(f: F) -> MapErrLayer<F>

Returns a new Layer that produces MapErr services.

This is a convenience function that simply calls MapErrLayer::new.

impl<M, S, Target, Request> MakeService for MapErr<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <M as MakeService<Target, Request>>::MakeError>>
fn make_service(self: &mut Self, target: Target) -> <M as MakeService<Target, Request>>::Future

impl<S, F> Debug for MapErr<S, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S, F> Freeze for MapErr<S, F>

impl<S, F> RefUnwindSafe for MapErr<S, F>

impl<S, F> Send for MapErr<S, F>

impl<S, F> Sync for MapErr<S, F>

impl<S, F> Unpin for MapErr<S, F>

impl<S, F> UnsafeUnpin for MapErr<S, F>

impl<S, F> UnwindSafe for MapErr<S, F>

impl<S, F, Request, Error> Service for MapErr<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn call(self: &mut Self, request: Request) -> <Self as >::Future

impl<S: $crate::clone::Clone, F: $crate::clone::Clone> Clone for MapErr<S, F>

fn clone(self: &Self) -> MapErr<S, F>

impl<T> Any for MapErr<S, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MapErr<S, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MapErr<S, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MapErr<S, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MapErr<S, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for MapErr<S, F>

impl<T> ToOwned for MapErr<S, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for MapErr<S, F>

impl<T, Request> ServiceExt for MapErr<S, F>

impl<T, U> Into for MapErr<S, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MapErr<S, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MapErr<S, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>