Struct MapRequest

struct MapRequest<S, F> { ... }

Service returned by the MapRequest combinator.

Implementations

impl<S, F> MapRequest<S, F>

const fn new(inner: S, f: F) -> Self

Creates a new MapRequest service.

fn layer(f: F) -> MapRequestLayer<F>

Returns a new Layer that produces MapRequest services.

This is a convenience function that simply calls MapRequestLayer::new.

impl<M, S, Target, Request> MakeService for MapRequest<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <M as MakeService<Target, Request>>::MakeError>>
fn make_service(self: &mut Self, target: Target) -> <M as MakeService<Target, Request>>::Future

impl<S, F> Debug for MapRequest<S, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S, F> Freeze for MapRequest<S, F>

impl<S, F> RefUnwindSafe for MapRequest<S, F>

impl<S, F> Send for MapRequest<S, F>

impl<S, F> Sync for MapRequest<S, F>

impl<S, F> Unpin for MapRequest<S, F>

impl<S, F> UnsafeUnpin for MapRequest<S, F>

impl<S, F> UnwindSafe for MapRequest<S, F>

impl<S, F, R1, R2> Service for MapRequest<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <S as >::Error>>
fn call(self: &mut Self, request: R1) -> <S as >::Future

impl<S: $crate::clone::Clone, F: $crate::clone::Clone> Clone for MapRequest<S, F>

fn clone(self: &Self) -> MapRequest<S, F>

impl<T> Any for MapRequest<S, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MapRequest<S, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MapRequest<S, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MapRequest<S, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MapRequest<S, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for MapRequest<S, F>

impl<T> ToOwned for MapRequest<S, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for MapRequest<S, F>

impl<T, Request> ServiceExt for MapRequest<S, F>

impl<T, U> Into for MapRequest<S, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MapRequest<S, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MapRequest<S, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>