Struct MapResponse

struct MapResponse<S, F> { ... }

Service returned by the map_response combinator.

Implementations

impl<S, F> MapResponse<S, F>

const fn new(inner: S, f: F) -> Self

Creates a new MapResponse service.

fn layer(f: F) -> MapResponseLayer<F>

Returns a new Layer that produces MapResponse services.

This is a convenience function that simply calls MapResponseLayer::new.

impl<M, S, Target, Request> MakeService for MapResponse<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <M as MakeService<Target, Request>>::MakeError>>
fn make_service(self: &mut Self, target: Target) -> <M as MakeService<Target, Request>>::Future

impl<S, F> Debug for MapResponse<S, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S, F> Freeze for MapResponse<S, F>

impl<S, F> RefUnwindSafe for MapResponse<S, F>

impl<S, F> Send for MapResponse<S, F>

impl<S, F> Sync for MapResponse<S, F>

impl<S, F> Unpin for MapResponse<S, F>

impl<S, F> UnsafeUnpin for MapResponse<S, F>

impl<S, F> UnwindSafe for MapResponse<S, F>

impl<S, F, Request, Response> Service for MapResponse<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn call(self: &mut Self, request: Request) -> <Self as >::Future

impl<S: $crate::clone::Clone, F: $crate::clone::Clone> Clone for MapResponse<S, F>

fn clone(self: &Self) -> MapResponse<S, F>

impl<T> Any for MapResponse<S, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for MapResponse<S, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for MapResponse<S, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for MapResponse<S, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for MapResponse<S, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for MapResponse<S, F>

impl<T> ToOwned for MapResponse<S, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for MapResponse<S, F>

impl<T, Request> ServiceExt for MapResponse<S, F>

impl<T, U> Into for MapResponse<S, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for MapResponse<S, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for MapResponse<S, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>