Struct Oneshot

struct Oneshot<S: Service<Req>, Req> { ... }

A Future consuming a Service and request, waiting until the Service is ready, and then calling Service::call with the request, and waiting for that Future.

Implementations

impl<S, Req> Oneshot<S, Req>

const fn new(svc: S, req: Req) -> Self

impl<'__pin, S: Service<Req>, Req> Unpin for Oneshot<S, Req>

impl<F> IntoFuture for Oneshot<S, Req>

fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture

impl<F, T, E> TryFuture for Oneshot<S, Req>

fn try_poll(self: Pin<&mut F>, cx: &mut Context<'_>) -> Poll<<F as Future>::Output>

impl<Fut> TryFutureExt for Oneshot<S, Req>

impl<S, Req> Freeze for Oneshot<S, Req>

impl<S, Req> Future for Oneshot<S, Req>

fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>

impl<S, Req> RefUnwindSafe for Oneshot<S, Req>

impl<S, Req> Send for Oneshot<S, Req>

impl<S, Req> Sync for Oneshot<S, Req>

impl<S, Req> UnsafeUnpin for Oneshot<S, Req>

impl<S, Req> UnwindSafe for Oneshot<S, Req>

impl<S: $crate::fmt::Debug + Service<Req>, Req: $crate::fmt::Debug> Debug for Oneshot<S, Req>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T> Any for Oneshot<S, Req>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Oneshot<S, Req>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Oneshot<S, Req>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for Oneshot<S, Req>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> FutureExt for Oneshot<S, Req>

impl<T> Instrument for Oneshot<S, Req>

impl<T> WithSubscriber for Oneshot<S, Req>

impl<T, U> Into for Oneshot<S, Req>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Oneshot<S, Req>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Oneshot<S, Req>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>