Struct ReadyOneshot
struct ReadyOneshot<T, Request> { ... }
A Future that yields the service when it is ready to accept a request.
ReadyOneshot values are produced by ServiceExt::ready_oneshot.
Implementations
impl<T, Request> ReadyOneshot<T, Request>
const fn new(service: T) -> Self
impl<F> IntoFuture for ReadyOneshot<T, Request>
fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture
impl<F, T, E> TryFuture for ReadyOneshot<T, Request>
fn try_poll(self: Pin<&mut F>, cx: &mut Context<'_>) -> Poll<<F as Future>::Output>
impl<Fut> TryFutureExt for ReadyOneshot<T, Request>
impl<T> Any for ReadyOneshot<T, Request>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ReadyOneshot<T, Request>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ReadyOneshot<T, Request>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ReadyOneshot<T, Request>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> FutureExt for ReadyOneshot<T, Request>
impl<T> Instrument for ReadyOneshot<T, Request>
impl<T> WithSubscriber for ReadyOneshot<T, Request>
impl<T, Request> Debug for ReadyOneshot<T, Request>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<T, Request> Freeze for ReadyOneshot<T, Request>
impl<T, Request> Future for ReadyOneshot<T, Request>
fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>
impl<T, Request> RefUnwindSafe for ReadyOneshot<T, Request>
impl<T, Request> Send for ReadyOneshot<T, Request>
impl<T, Request> Sync for ReadyOneshot<T, Request>
impl<T, Request> Unpin for ReadyOneshot<T, Request>
impl<T, Request> UnsafeUnpin for ReadyOneshot<T, Request>
impl<T, Request> UnwindSafe for ReadyOneshot<T, Request>
impl<T, U> Into for ReadyOneshot<T, Request>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ReadyOneshot<T, Request>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ReadyOneshot<T, Request>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>