Struct Then

struct Then<S, F> { ... }

Service returned by the then combinator.

Implementations

impl<S, F> Then<S, F>

const fn new(inner: S, f: F) -> Self

Creates a new Then service.

fn layer(f: F) -> ThenLayer<F>

Returns a new Layer that produces Then services.

This is a convenience function that simply calls ThenLayer::new.

impl<M, S, Target, Request> MakeService for Then<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <M as MakeService<Target, Request>>::MakeError>>
fn make_service(self: &mut Self, target: Target) -> <M as MakeService<Target, Request>>::Future

impl<S, F> Debug for Then<S, F>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<S, F> Freeze for Then<S, F>

impl<S, F> RefUnwindSafe for Then<S, F>

impl<S, F> Send for Then<S, F>

impl<S, F> Sync for Then<S, F>

impl<S, F> Unpin for Then<S, F>

impl<S, F> UnsafeUnpin for Then<S, F>

impl<S, F> UnwindSafe for Then<S, F>

impl<S, F, Request, Response, Error, Fut> Service for Then<S, F>

fn poll_ready(self: &mut Self, cx: &mut Context<'_>) -> Poll<Result<(), <Self as >::Error>>
fn call(self: &mut Self, request: Request) -> <Self as >::Future

impl<S: $crate::clone::Clone, F: $crate::clone::Clone> Clone for Then<S, F>

fn clone(self: &Self) -> Then<S, F>

impl<T> Any for Then<S, F>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Then<S, F>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Then<S, F>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Then<S, F>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> From for Then<S, F>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for Then<S, F>

impl<T> ToOwned for Then<S, F>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> WithSubscriber for Then<S, F>

impl<T, Request> ServiceExt for Then<S, F>

impl<T, U> Into for Then<S, F>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Then<S, F>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Then<S, F>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>