Trait Predicate
trait Predicate<Request>
Checks a request synchronously.
Associated Types
type RequestThe type of requests returned by
check.This request is forwarded to the inner service if the predicate succeeds.
Required Methods
fn check(self: &mut Self, request: Request) -> Result<<Self as >::Request, BoxError>Check whether the given request should be forwarded.
If the future resolves with
Ok, the request is forwarded to the inner service.
Implementors
impl<F, T, R, E> Predicate for F