Trait tower::hedge::Policy [−][src]
pub trait Policy<Request> {
fn clone_request(&self, req: &Request) -> Option<Request>;
fn can_retry(&self, req: &Request) -> bool;
}This is supported on crate feature
hedge only.A policy which describes which requests can be cloned and then whether those requests should be retried.
Required methods
fn clone_request(&self, req: &Request) -> Option<Request>[src]
Called when the request is first received to determine if the request is retryable.
fn can_retry(&self, req: &Request) -> bool[src]
Called after the hedge timeout to determine if the hedge retry should be issued.