pub trait Load {
type Metric: PartialOrd;
// Required method
fn load(&self) -> Self::Metric;
}Expand description
Types that implement this trait can give an estimate of how loaded they are.
See the module documentation for more details.
Required Associated Types
Sourcetype Metric: PartialOrd
type Metric: PartialOrd
A comparable load metric.
Lesser values indicate that the service is less loaded, and should be preferred for new requests over another service with a higher value.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".